@@ -13,6 +13,8 @@ OC.L10N.register(
     "More activities" : "Plus d’activités",
     "Daily activity summary for %s" : "Résumé de l’activité du jour pour %s",
     "_and %n more…_::_and %n more…_" : ["et %n de plus…","et %n en plus…","et %n de plus…"],
+    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Vous pouvez désactiver les e-mails quotidiens récapitulatifs dans les <a href=\"%s\">paramètres.</a>",
+    "You can disable daily digest emails in the settings: %s" : "Vous pouvez désactiver les e-mails quotidiens récapitulatifs dans les paramètres: %s",
     "All activities" : "Toutes les activités",
     "By others" : "Des autres",
     "By you" : "De vous",
@@ -21,11 +23,13 @@ OC.L10N.register(
     "Hello %s," : "Bonjour %s,",
     "There was some activity at %s" : "Il y a eu de l’activité sur %s",
     "_and %n more _::_and %n more _" : ["et %n autre","et %n autres","et %n autres"],
+    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Vous pouvez changer la fréquence de ces e-mails ou les désactiver dans les <a href=\"%s\">paramètres</a>.",
+    "You can change the frequency of these emails or disable them in the settings: %s" : "Vous pouvez changer la fréquence de ces e-mails ou les désactiver dans les paramètres : %s",
     "Mail" : "E-mail",
     "Push" : "Push",
     "Activity" : "Activité",
     "Notifications" : "Notifications",
-    "This application enables people to view a log of activities about them, their files or other data." : "Cette application permet aux personnes de visualiser un journal des activités les concernant, leurs fichiers ou d’autres données.",
+    "This application enables people to view a log of activities about them, their files or other data." : "Cette application permet aux personnes de visualiser les logs des activités les concernant, leurs fichiers ou d’autres données.",
     "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Cette application permet aux utilisateurs de visualiser les actions relatives à leurs fichiers et données dans Nextcloud.\n\t\tChaque personne peut configurer ses options d’activité individuelle dans les paramètres personnels,\n\t\tpour choisir quelles activités devraient être poussées vers les téléphones mobiles, envoyées par e-mail,\n\t\tou si un résumé quotidien est envoyé chaque matin.\n\t\tPlus d’informations sont accessibles dans la documentation d’Activité.",
     "Send email" : "Envoyer un e-mail",
     "Send push notification" : "Envoyer des notifications push",
