@@ -64,7 +64,7 @@ class MailQueueHandler {
 	 * @param $limit Number of users we want to send an email to
 	 * @param $sendTime The latest send time
 	 * @param $forceSending Ignores latest send and just sends all emails
-	 * @param $restrictEmails null or one of UserSettings::EMAIL_SEND_*
+	 * @param $restrictEmails null or one of UserSettings::EMAIL_SEND_*, will overwrite force send
 	 * @return int Number of users we sent an email to
 	 */
 	public function sendEmails(int $limit, int $sendTime, bool $forceSending = false, ?int $restrictEmails = null): int {
@@ -91,13 +91,7 @@ class MailQueueHandler {
 				continue;
 			}
 
-			try {
-				$userObject = $this->userManager->get($user);
-			} catch (\Exception $e) {
-				$this->logger->error('An error happened while trying to find ' . $user . ', skipping', ['exception' => $e]);
-				continue;
-			}
-
+			$userObject = $this->userManager->get($user);
 			$email = $userObject ? $userObject->getEMailAddress() : '';
 			if (empty($email)) {
 				// The user did not setup an email address
@@ -147,12 +141,6 @@ class MailQueueHandler {
 			$query->setMaxResults($limit);
 		}
 
-		if ($forceSending) {
-			$query->where($query->expr()->lt('amq_timestamp', $query->createNamedParameter($latestSend)));
-		} else {
-			$query->where($query->expr()->lt('amq_latest_send', $query->createNamedParameter($latestSend)));
-		}
-
 		if ($restrictEmails !== null) {
 			if ($restrictEmails === UserSettings::EMAIL_SEND_HOURLY) {
 				$query->where($query->expr()->eq('amq_timestamp', $query->func()->subtract('amq_latest_send', $query->expr()->literal(3600))));
@@ -163,6 +151,22 @@ class MailQueueHandler {
 			} elseif ($restrictEmails === UserSettings::EMAIL_SEND_ASAP) {
 				$query->where($query->expr()->eq('amq_timestamp', 'amq_latest_send'));
 			}
+
+			$result = $query->executeQuery();
+
+			$affectedUsers = [];
+			while ($row = $result->fetch()) {
+				$affectedUsers[] = $row['amq_affecteduser'];
+			}
+			$result->closeCursor();
+
+			return $affectedUsers;
+		}
+
+		if ($forceSending) {
+			$query->where($query->expr()->lt('amq_timestamp', $query->createNamedParameter($latestSend)));
+		} else {
+			$query->where($query->expr()->lt('amq_latest_send', $query->createNamedParameter($latestSend)));
 		}
 
 		$result = $query->executeQuery();
@@ -300,7 +304,7 @@ class MailQueueHandler {
 			function ($event) use ($timezone, $l) {
 				return [
 					'event' => $event,
-					'relativeDateTime' => $this->dateFormatter->formatDateTimeRelativeDay(
+					'dateTime' => $this->dateFormatter->formatDateTime(
 						$event->getTimestamp(),
 						'long', 'short',
 						new \DateTimeZone($timezone), $l
@@ -328,15 +332,20 @@ class MailQueueHandler {
 
 		foreach ($activityEvents as $activity) {
 			$event = $activity['event'];
-			$relativeDateTime = $activity['relativeDateTime'];
+			$activityDateTime = $activity['dateTime'];
 
-			$template->addBodyListItem($this->getHTMLSubject($event), $relativeDateTime, $event->getIcon(), $event->getParsedSubject());
+			$template->addBodyListItem($this->getHTMLSubject($event), $activityDateTime, $event->getIcon(), $event->getParsedSubject());
 		}
 
 		if ($skippedCount) {
 			$template->addBodyListItem($l->n('and %n more ', 'and %n more ', $skippedCount));
 		}
 
+		$template->addBodyText(
+			$l->t('You can change the frequency of these emails or disable them in the <a href="%s">settings</a>.', $this->urlGenerator->linkToRouteAbsolute('settings.PersonalSettings.index', ['section' => 'notifications'])),
+			$l->t('You can change the frequency of these emails or disable them in the settings: %s', $this->urlGenerator->linkToRouteAbsolute('settings.PersonalSettings.index', ['section' => 'notifications']))
+		);
+
 		$template->addFooter('', $lang);
 
 		$message = $this->mailer->createMessage();
