@@ -87,18 +87,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Inicialización de la aplicación Círculos",
     "Fresh installation status" : "Estado de instalación nueva",
     "Building Local Database" : "Creando la base de datos local",
-    "Testing Basic Circle Creation" : "Probando la creación básica de un Círculo",
     "Adding local users and moderators" : "Agregando usuarios locales y moderadores",
     "Files" : "Archivo",
-    "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
     "This member is not a moderator" : "Este miembro no es un moderador",
     "Insufficient privileges" : "Privilegios insuficientes",
     "This member does not exist" : "Este miembro no existe",
     "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
-    "You are already a member of this circle" : "Ya eres un miembro de este círculo",
-    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
-    "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
-    "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo",
     "Accept" : "Aceptar",
     "Refuse" : "Rechazar",
     "%s" : "%s",
@@ -119,6 +113,11 @@ OC.L10N.register(
     "Size" : "Tamaño",
     "Modified" : "Modificado",
     "Shared to Circles" : "Compartido a Círculos",
-    "Circle" : "Círculo"
+    "Testing Basic Circle Creation" : "Probando la creación básica de un Círculo",
+    "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
+    "You are already a member of this circle" : "Ya eres un miembro de este círculo",
+    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
+    "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
+    "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
