@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Equipes",
     "You created the team {circle}" : "Você criou a equipe {circle}",
     "{author} created the team {circle}" : "{author} criou a equipe {circle}",
     "You deleted {circle}" : "Você excluiu {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} solicitou juntar-se à {circle}",
     "You are the new owner of {circle}" : "Você é o novo proprietário de {circle}",
     "{member} is the new owner of {circle}" : "{member} é o novo proprietário de {circle}",
+    "Teams" : "Equipes",
     "On events happening in a <strong>team</strong> of which you are a member" : "Em eventos que acontecem em uma <strong>equipe</strong> da qual você é membro",
     "Any important event in a <strong>team</strong> you are moderating" : "Qualquer evento importante em uma <strong>equipe</strong> que você está moderando",
     "On global events happening in any <strong>team</strong>" : "Em eventos globais que acontecem em qualquer <strong>equipe</strong>",
@@ -76,8 +76,10 @@ OC.L10N.register(
     "Nextcloud Group" : "Grupo Nextcloud",
     "Email address" : "Endereço de e-mail",
     "Contact" : "Contato",
-    "Circle" : "Círculo",
+    "Team" : "Equipe",
     "Nextcloud App" : "Aplicativo Nextcloud",
+    "Teams App" : "Aplicativo Equipes",
+    "Admin Command Line" : "Linha de Comando do Administrador",
     "Member" : "Membro",
     "Moderator" : "Moderador",
     "Admin" : "Administrador",
@@ -104,12 +106,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Inicialização do Aplicativo Círculos",
     "Fresh installation status" : "Novo status de instalação",
     "Building Local Database" : "Construindo banco de dados local",
-    "Testing Basic Circle Creation" : "Teste básico de criação de círculo",
     "Adding local users and moderators" : "Adicionando usuários locais e moderadores",
     "Show all teams" : "Mostrar todas as equipes",
     "Create a new team" : "Criar uma nova equipe",
     "Files" : "Arquivos",
-    "This feature is not available for personal circles" : "Este recurso não está disponível para círculos pessoais",
     "The team is not federated" : "A equipe não é federada",
     "You cannot join this team" : "Você não pode entrar nesta equipe",
     "This member is not a moderator" : "Este membro não é moderador",
@@ -117,10 +117,6 @@ OC.L10N.register(
     "This member does not exist" : "Este membro não existe",
     "This member is the owner of the team" : "Este membro é o proprietário da equipe",
     "Level cannot be changed for this type of member" : "O nível não pode ser mudado para este tipo de usuário",
-    "You are already a member of this circle" : "Você já é membro deste círculo",
-    "You have been blocked from this circle" : "Você foi bloqueado neste círculo",
-    "The account is already a member of this circle" : "A conta já é membro deste círculo",
-    "The account has already been invited into this circle" : "A conta já foi convidada para este círculo",
     "%s (Team owned by %s)" : "%s (Equipe de propriedade de %s)",
     "You are now a member of the Team \"%2$s\"" : "Agora você é um membro da Equipe \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Você foi convidado por %1$s para fazer parte da equipe \"%2$s\"",
@@ -134,6 +130,9 @@ OC.L10N.register(
     "You have no permission to create a new team" : "Você não tem permissão para criar uma nova equipe",
     "%s shared a file with \"%s\"." : "%s compartilhou um arquivo com \"%s\".",
     "%s shared a file with you." : "%s compartilhou um arquivo com você.",
+    "%1$s shared %2$s with %3$s" : "%1$s compartilhou %2$s com %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s compartilhou %2$s com \"%3$s\"",
+    "Open %s" : "Abrir %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou algum conteúdo com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-lo.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
     "Password to access content shared with you by %1$s" : "Senha para acessar o conteúdo compartilhado com você por %1$s",
@@ -141,16 +140,24 @@ OC.L10N.register(
     "This item is already shared with this team" : "Este item já está compartilhado com esta equipe",
     "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Equipes permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
+    "Failed to load teams" : "Falha ao carregar equipes",
+    "Try again" : "Tentar novamente",
+    "No teams found" : "Nenhuma equipe encontrada",
+    "Join or create teams to see them here." : "Junte-se ou crie equipes para vê-las aqui.",
+    "Create your first team" : "Crie sua primeira equipe",
+    "Loading…" : "Carregando…",
+    "More teams" : "Mais equipes",
     "No files in here" : "Nenhum arquivo aqui",
     "No entries found in this folder" : "Sem entradas nesta pasta",
     "Name" : "Nome",
     "Size" : "Tamanho",
     "Modified" : "Modificado",
-    "Teams' files" : "Arquivos das equipes",
-    "Select team to filter by" : "Selecione uma equipe para filtrar",
-    "No teams found" : "Nenhuma equipe encontrada",
-    "Please select teams to filter by" : "Selecione equipes para filtrar",
-    "No files found for the selected teams" : "Nenhum arquivo encontrado para as equipes selecionadas",
-    "Shared to Circles" : "Compartilhado com Círculos"
+    "Shared to Circles" : "Compartilhado com Círculos",
+    "Testing Basic Circle Creation" : "Teste básico de criação de círculo",
+    "This feature is not available for personal circles" : "Este recurso não está disponível para círculos pessoais",
+    "You are already a member of this circle" : "Você já é membro deste círculo",
+    "You have been blocked from this circle" : "Você foi bloqueado neste círculo",
+    "The account is already a member of this circle" : "A conta já é membro deste círculo",
+    "The account has already been invited into this circle" : "A conta já foi convidada para este círculo"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
