@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Teams",
     "You created the team {circle}" : "Du skapade teamet {circle}",
     "{author} created the team {circle}" : "{author} skapade teamet {circle}",
     "You deleted {circle}" : "Du tog bort {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} skickade en begäran att gå med i {circle}",
     "You are the new owner of {circle}" : "Du är ny ägare av {circle}",
     "{member} is the new owner of {circle}" : "{member} är ny ägare av {circle}",
+    "Teams" : "Teams",
     "On events happening in a <strong>team</strong> of which you are a member" : "Vid händelser i ett <strong>team</strong> där du är medlem",
     "Any important event in a <strong>team</strong> you are moderating" : "Alla viktiga händelser i ett <strong>team</strong> du modererar",
     "On global events happening in any <strong>team</strong>" : "Vid globala händelser som händer i något <strong>team</strong>",
@@ -76,8 +76,10 @@ OC.L10N.register(
     "Nextcloud Group" : "Nextcloud-grupp",
     "Email address" : "E-postadress",
     "Contact" : "Kontakta",
-    "Circle" : "Cirkel",
+    "Team" : "Team",
     "Nextcloud App" : "Nextcloud-app",
+    "Teams App" : "Teams App",
+    "Admin Command Line" : "Kommandoraden för administratörer",
     "Member" : "Medlem",
     "Moderator" : "Moderator",
     "Admin" : "Administratör",
@@ -104,12 +106,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Cirklar appinitiering",
     "Fresh installation status" : "Nyinstallationsstatus",
     "Building Local Database" : "Bygger lokal databas",
-    "Testing Basic Circle Creation" : "Testar grundläggande Cirkel-skapande",
     "Adding local users and moderators" : "Lägger till lokala användare och moderatorer ",
     "Show all teams" : "Visa alla team",
     "Create a new team" : "Skapa ett nytt team",
     "Files" : "Filer",
-    "This feature is not available for personal circles" : "Funktionen är inte tillgänglig för personliga cirklar",
     "The team is not federated" : "Detta team är inte federerat",
     "You cannot join this team" : "Du kan inte gå med i detta team",
     "This member is not a moderator" : "Medlemmen är inte en moderator",
@@ -117,10 +117,6 @@ OC.L10N.register(
     "This member does not exist" : "Medlemmen finns inte",
     "This member is the owner of the team" : "Denna medlem är ägaren av teamet",
     "Level cannot be changed for this type of member" : "Nivå kan inte ändras för medlemstypen",
-    "You are already a member of this circle" : "Du är redan medlem i denna cirkel",
-    "You have been blocked from this circle" : "Du har blockerats från denna cirkel",
-    "The account is already a member of this circle" : "Kontot är redan medlem av denna cirkel",
-    "The account has already been invited into this circle" : "Kontot har redan bjudits in till denna cirkel",
     "%s (Team owned by %s)" : "%s (Team ägs av %s)",
     "You are now a member of the Team \"%2$s\"" : "Du är nu medlem i Team \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Du har blivit inbjuden av %1$s till Team \"%2$s\"",
@@ -134,6 +130,9 @@ OC.L10N.register(
     "You have no permission to create a new team" : "Du har inte behörighet att skapa ett nytt team",
     "%s shared a file with \"%s\"." : "%s delade en fil med \"%s\".",
     "%s shared a file with you." : "%s delade en fil med dig.",
+    "%1$s shared %2$s with %3$s" : "%1$s delade %2$s med %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s delade %2$s med \"%3$s\"",
+    "Open %s" : "Öppna %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delade innehåll med dig.\nDu borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delade innehåll med dig. Du borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
     "Password to access content shared with you by %1$s" : "Lösenord för tillgång till innehåll delat med dig av 1%1$s",
@@ -141,16 +140,24 @@ OC.L10N.register(
     "This item is already shared with this team" : "Detta objektet delas redan med detta team",
     "Bring cloud-users closer together." : "För moln-användare närmare varandra.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams låter användare att skapa egna grupper av användare/kollegor/vänner.\nDessa grupper av användare kan sedan användas av alla andra appar vid delning.",
+    "Failed to load teams" : "Kunde inte läsa in team",
+    "Try again" : "Försök igen",
+    "No teams found" : "Inga team hittades",
+    "Join or create teams to see them here." : "Gå med i eller skapa team för att se dem här.",
+    "Create your first team" : "Skapa ditt första team",
+    "Loading…" : "Laddar...",
+    "More teams" : "Fler team",
     "No files in here" : "Inga filer här",
     "No entries found in this folder" : "Inga objekt funna i denna mapp",
     "Name" : "Namn",
     "Size" : "Storlek",
     "Modified" : "Ändrad",
-    "Teams' files" : "Teams filer",
-    "Select team to filter by" : "Välj team att filtrera efter",
-    "No teams found" : "Inga team hittades",
-    "Please select teams to filter by" : "Välj team att filtrera efter",
-    "No files found for the selected teams" : "Inga filer hittade för valda team",
-    "Shared to Circles" : "Delad med Cirklar"
+    "Shared to Circles" : "Delad med Cirklar",
+    "Testing Basic Circle Creation" : "Testar grundläggande Cirkel-skapande",
+    "This feature is not available for personal circles" : "Funktionen är inte tillgänglig för personliga cirklar",
+    "You are already a member of this circle" : "Du är redan medlem i denna cirkel",
+    "You have been blocked from this circle" : "Du har blockerats från denna cirkel",
+    "The account is already a member of this circle" : "Kontot är redan medlem av denna cirkel",
+    "The account has already been invited into this circle" : "Kontot har redan bjudits in till denna cirkel"
 },
 "nplurals=2; plural=(n != 1);");
