@@ -14,7 +14,7 @@ use OCP\IL10N;
 
 class SettingAsNonMember implements ISetting {
 	public function __construct(
-		protected IL10N $l10n
+		protected IL10N $l10n,
 	) {
 	}
 
@@ -39,8 +39,8 @@ class SettingAsNonMember implements ISetting {
 
 	/**
 	 * @return int whether the filter should be rather on the top or bottom of
-	 * the admin section. The filters are arranged in ascending order of the
-	 * priority values. It is required to return a value between 0 and 100.
+	 *             the admin section. The filters are arranged in ascending order of the
+	 *             priority values. It is required to return a value between 0 and 100.
 	 * @since 11.0.0
 	 */
 	public function getPriority() {
