@@ -50,7 +50,7 @@ class CirclesCreate extends Base {
 	 */
 	public function __construct(
 		FederatedUserService $federatedUserService,
-		CircleService $circleService
+		CircleService $circleService,
 	) {
 		parent::__construct();
 		$this->federatedUserService = $federatedUserService;
@@ -61,16 +61,16 @@ class CirclesCreate extends Base {
 	protected function configure() {
 		parent::configure();
 		$this->setName('circles:manage:create')
-			 ->setDescription('create a new circle')
-			 ->addArgument('owner', InputArgument::REQUIRED, 'owner of the circle')
-			 ->addArgument('name', InputArgument::REQUIRED, 'name of the circle')
-			 ->addOption('personal', '', InputOption::VALUE_NONE, 'create a personal circle')
-			 ->addOption('local', '', InputOption::VALUE_NONE, 'create a local circle')
-			 ->addOption('status-code', '', InputOption::VALUE_NONE, 'display status code on exception')
-			 ->addOption(
-			 	'type', '', InputOption::VALUE_REQUIRED, 'type of the owner',
-			 	Member::$TYPE[Member::TYPE_SINGLE]
-			 );
+			->setDescription('create a new circle')
+			->addArgument('owner', InputArgument::REQUIRED, 'owner of the circle')
+			->addArgument('name', InputArgument::REQUIRED, 'name of the circle')
+			->addOption('personal', '', InputOption::VALUE_NONE, 'create a personal circle')
+			->addOption('local', '', InputOption::VALUE_NONE, 'create a local circle')
+			->addOption('status-code', '', InputOption::VALUE_NONE, 'display status code on exception')
+			->addOption(
+				'type', '', InputOption::VALUE_REQUIRED, 'type of the owner',
+				Member::$TYPE[Member::TYPE_SINGLE]
+			);
 	}
 
 
@@ -104,7 +104,7 @@ class CirclesCreate extends Base {
 		} catch (FederatedItemException $e) {
 			if ($input->getOption('status-code')) {
 				throw new FederatedItemException(
-					' [' . get_class($e) . ', ' . $e->getStatus() . ']' . "\n" . $e->getMessage()
+					' [' . get_class($e) . ', ' . ((string)$e->getStatus()) . ']' . "\n" . $e->getMessage()
 				);
 			}
 
