@@ -83,7 +83,7 @@ class Crypt {
 	/**
 	 * create new private/public key-pair for user
 	 *
-	 * @return array|bool
+	 * @return array{publicKey: string, privateKey: string}|false
 	 */
 	public function createKeyPair() {
 		$res = $this->getOpenSSLPKey();
@@ -155,7 +155,7 @@ class Crypt {
 			$this->getCipher());
 
 		// Create a signature based on the key as well as the current version
-		$sig = $this->createSignature($encryptedContent, $passPhrase.'_'.$version.'_'.$position);
+		$sig = $this->createSignature($encryptedContent, $passPhrase . '_' . $version . '_' . $position);
 
 		// combine content to encrypt the IV identifier and actual IV
 		$catFile = $this->concatIV($encryptedContent, $iv);
@@ -342,9 +342,8 @@ class Crypt {
 	 * @param string $privateKey
 	 * @param string $password
 	 * @param string $uid for regular users, empty for system keys
-	 * @return false|string
 	 */
-	public function decryptPrivateKey($privateKey, $password = '', $uid = '') {
+	public function decryptPrivateKey($privateKey, $password = '', $uid = '') : string|false {
 		$header = $this->parseHeader($privateKey);
 
 		if (isset($header['cipher'])) {
@@ -457,7 +456,7 @@ class Crypt {
 			if ($enforceSignature) {
 				throw new GenericEncryptionException('Bad Signature', $this->l->t('Bad Signature'));
 			} else {
-				$this->logger->info("Signature check skipped", ['app' => 'encryption']);
+				$this->logger->info('Signature check skipped', ['app' => 'encryption']);
 			}
 		}
 	}
@@ -751,7 +750,7 @@ class Crypt {
 		$result = false;
 
 		// check if RC4 is used
-		if (strcasecmp($cipher_algo, "rc4") === 0) {
+		if (strcasecmp($cipher_algo, 'rc4') === 0) {
 			// decrypt the intermediate key with RSA
 			if (openssl_private_decrypt($encrypted_key, $intermediate, $private_key, OPENSSL_PKCS1_PADDING)) {
 				// decrypt the file key with the intermediate key
@@ -760,7 +759,7 @@ class Crypt {
 				$result = (strlen($output) === strlen($data));
 			}
 		} else {
-			throw new DecryptionFailedException('Unsupported cipher '.$cipher_algo);
+			throw new DecryptionFailedException('Unsupported cipher ' . $cipher_algo);
 		}
 
 		return $result;
@@ -776,7 +775,7 @@ class Crypt {
 		$result = false;
 
 		// check if RC4 is used
-		if (strcasecmp($cipher_algo, "rc4") === 0) {
+		if (strcasecmp($cipher_algo, 'rc4') === 0) {
 			// make sure that there is at least one public key to use
 			if (count($public_key) >= 1) {
 				// generate the intermediate key
@@ -807,7 +806,7 @@ class Crypt {
 				}
 			}
 		} else {
-			throw new EncryptionFailedException('Unsupported cipher '.$cipher_algo);
+			throw new EncryptionFailedException('Unsupported cipher ' . $cipher_algo);
 		}
 
 		return $result;
