@@ -25,25 +25,10 @@ class DBConfigService {
 	public const APPLICABLE_TYPE_GROUP = 2;
 	public const APPLICABLE_TYPE_USER = 3;
 
-	/**
-	 * @var IDBConnection
-	 */
-	private $connection;
-
-	/**
-	 * @var ICrypto
-	 */
-	private $crypto;
-
-	/**
-	 * DBConfigService constructor.
-	 *
-	 * @param IDBConnection $connection
-	 * @param ICrypto $crypto
-	 */
-	public function __construct(IDBConnection $connection, ICrypto $crypto) {
-		$this->connection = $connection;
-		$this->crypto = $crypto;
+	public function __construct(
+		private IDBConnection $connection,
+		private ICrypto $crypto,
+	) {
 	}
 
 	public function getMountById(int $mountId): ?array {
@@ -113,12 +98,12 @@ class DBConfigService {
 			)
 			)
 			->groupBy(['a.mount_id']);
-		$stmt = $query->execute();
+		$stmt = $query->executeQuery();
 		$result = $stmt->fetchAll();
 		$stmt->closeCursor();
 
 		foreach ($result as $row) {
-			if ((int) $row['count'] > 1) {
+			if ((int)$row['count'] > 1) {
 				$this->removeApplicable($row['mount_id'], $applicableType, $applicableId);
 			} else {
 				$this->removeMount($row['mount_id']);
@@ -244,7 +229,7 @@ class DBConfigService {
 				'priority' => $builder->createNamedParameter($priority, IQueryBuilder::PARAM_INT),
 				'type' => $builder->createNamedParameter($type, IQueryBuilder::PARAM_INT)
 			]);
-		$query->execute();
+		$query->executeStatement();
 		return $query->getLastInsertId();
 	}
 
@@ -257,22 +242,22 @@ class DBConfigService {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_mounts')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
-		$query->execute();
+		$query->executeStatement();
 
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_applicable')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
-		$query->execute();
+		$query->executeStatement();
 
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_config')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
-		$query->execute();
+		$query->executeStatement();
 
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_options')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
-		$query->execute();
+		$query->executeStatement();
 	}
 
 	/**
@@ -286,7 +271,7 @@ class DBConfigService {
 			->set('mount_point', $builder->createNamedParameter($newMountPoint))
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
 
-		$query->execute();
+		$query->executeStatement();
 	}
 
 	/**
@@ -300,7 +285,7 @@ class DBConfigService {
 			->set('auth_backend', $builder->createNamedParameter($newAuthBackend))
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
 
-		$query->execute();
+		$query->executeStatement();
 	}
 
 	/**
@@ -326,7 +311,7 @@ class DBConfigService {
 				->set('value', $builder->createNamedParameter($value, IQueryBuilder::PARAM_STR))
 				->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)))
 				->andWhere($builder->expr()->eq('key', $builder->createNamedParameter($key, IQueryBuilder::PARAM_STR)));
-			$query->execute();
+			$query->executeStatement();
 		}
 	}
 
@@ -349,7 +334,7 @@ class DBConfigService {
 				->set('value', $builder->createNamedParameter(json_encode($value), IQueryBuilder::PARAM_STR))
 				->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)))
 				->andWhere($builder->expr()->eq('key', $builder->createNamedParameter($key, IQueryBuilder::PARAM_STR)));
-			$query->execute();
+			$query->executeStatement();
 		}
 	}
 
@@ -378,11 +363,11 @@ class DBConfigService {
 			$query = $query->andWhere($builder->expr()->eq('value', $builder->createNamedParameter($value, IQueryBuilder::PARAM_STR)));
 		}
 
-		$query->execute();
+		$query->executeStatement();
 	}
 
 	private function getMountsFromQuery(IQueryBuilder $query) {
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		$mounts = $result->fetchAll();
 		$uniqueMounts = [];
 		foreach ($mounts as $mount) {
@@ -403,8 +388,8 @@ class DBConfigService {
 		$options = $this->getOptionsForMounts($mountIds);
 
 		return array_map(function ($mount, $applicable, $config, $options) {
-			$mount['type'] = (int) $mount['type'];
-			$mount['priority'] = (int) $mount['priority'];
+			$mount['type'] = (int)$mount['type'];
+			$mount['priority'] = (int)$mount['priority'];
 			$mount['applicable'] = $applicable;
 			$mount['config'] = $config;
 			$mount['options'] = $options;
@@ -433,7 +418,7 @@ class DBConfigService {
 			->from($table)
 			->where($builder->expr()->in('mount_id', $placeHolders));
 
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		$rows = $result->fetchAll();
 		$result->closeCursor();
 
@@ -443,7 +428,7 @@ class DBConfigService {
 		}
 		foreach ($rows as $row) {
 			if (isset($row['type'])) {
-				$row['type'] = (int) $row['type'];
+				$row['type'] = (int)$row['type'];
 			}
 			$result[$row['mount_id']][] = $row;
 		}
