@@ -8,7 +8,7 @@ OC.L10N.register(
     "Set file reminders" : "Установить напоминания о файлах",
     "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣Напоминания о файлах**\n\nУстановите напоминания о файлах.\n\nПримечание: чтобы использовать приложение \"Напоминания о файлах\", убедитесь, что приложение \"Уведомления\" установлено и включено. Приложение \"Уведомления\" предоставляет необходимые API-интерфейсы для правильной работы приложения \"Напоминания о файлах\".",
     "Set reminder for \"{fileName}\"" : "Установить напоминание для \"{fileName}\"",
-    "Set reminder at custom date & time" : "Установить напоминание на индивидуальную дату и время",
+    "Reminder at custom date & time" : "Напоминание в указанную дату и время",
     "Clear reminder" : "Очистить напоминание",
     "Please choose a valid date & time" : "Пожалуйста, выберите правильную дату и время",
     "Reminder set for \"{fileName}\"" : "Напоминание для \"{fileName}\"",
@@ -19,7 +19,7 @@ OC.L10N.register(
     "Cancel" : "Отмена",
     "Set reminder" : "Установить напоминание",
     "Reminder set" : "Установить напоминание",
-    "Set custom reminder" : "Установить особое напоминание",
+    "Custom reminder" : "Пользовательское напоминание",
     "Later today" : "Позже сегодня",
     "Set reminder for later today" : "Установить напоминание позднее сегодня",
     "Tomorrow" : "Завтра",
@@ -27,6 +27,8 @@ OC.L10N.register(
     "This weekend" : "Эта неделя",
     "Set reminder for this weekend" : "Установить напоминание на эти выходные",
     "Next week" : "Следующая неделя",
-    "Set reminder for next week" : "Установить напоминание на следующую неделю"
+    "Set reminder for next week" : "Установить напоминание на следующую неделю",
+    "Set reminder at custom date & time" : "Установить напоминание на индивидуальную дату и время",
+    "Set custom reminder" : "Установить особое напоминание"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
