@@ -1,16 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privado",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
-    "Federated" : "Federada",
-    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
-    "Published" : "Publicado",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
-    "Verify" : "Verificar",
-    "Verifying …" : "A verificar...",
     "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
     "Very weak password" : "Palavra-passe muito fraca",
     "Weak password" : "Palavra-passe fraca",
@@ -82,6 +72,7 @@ OC.L10N.register(
     "Administration" : "Administração",
     "Users" : "Utilizadores",
     "Additional settings" : "Definições adicionais",
+    "Assistant" : "Assistente",
     "Administration privileges" : "Privilégios de administração",
     "Overview" : "Visão Geral",
     "Basic settings" : "Definições básicas",
@@ -94,6 +85,8 @@ OC.L10N.register(
     "Background jobs" : "Tarefas de segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "A verificar",
+    "Verifying …" : "A verificar...",
+    "Verify" : "Verificar",
     "Internet connectivity" : "Conetividade da Internet",
     "Internet connectivity is disabled in configuration file." : "A conetividade da Internet está desativada no ficheiro de configuração.",
     "Disabled" : "Desativado",
@@ -118,6 +111,7 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será exibido na página de carregamento de ligações públicas quando a lista de ficheiros estiver oculta. ",
     "Limit to groups" : "Limitado a grupos",
     "Save changes" : "Guardar alterações",
+    "Default" : "Predefinido",
     "Update to {update}" : "Atualizar para {update}",
     "Remove" : "Remover",
     "Featured" : "Destacado",
@@ -140,14 +134,12 @@ OC.L10N.register(
     "Description" : "Descrição",
     "View in store" : "Ver na loja",
     "Visit website" : "Visitar o website",
-    "Admin documentation" : "Documentação do Administrador",
-    "Developer documentation" : "Documentação de Programador",
+    "Admin documentation" : "Documentação de administrador",
+    "Developer documentation" : "Documentação de programador",
     "Details" : "Detalhes",
     "All" : "Todos",
     "No results" : "Sem resultados",
     "Update to {version}" : "Atualizar para {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
     "Author" : "Autor",
     "Categories" : "Categorias",
@@ -160,6 +152,7 @@ OC.L10N.register(
     "Rate" : "Classificar",
     "Changelog" : "Registo de alterações",
     "Google Chrome for Android" : "Google Chrome para Android",
+    "{productName} Android app" : "{productName} Aplicação Android",
     "Sync client" : "Sincronizar cliente",
     "This session" : "Esta sessão",
     "{client} - {version} ({system})" : "{client} - {version} ({system})",
@@ -174,11 +167,12 @@ OC.L10N.register(
     "Devices & sessions" : "Sessões e dispositivos",
     "Web, desktop and mobile clients currently logged in to your account." : "Os clientes da Web, de PC e móveis estão atualmente autenticados na sua conta.",
     "Error while creating device token" : "Erro durante a criação do token do dispositivo",
-    "App name" : "Nome da App",
+    "App name" : "Nome da aplicação",
     "Create new app password" : "Criar nova palavra-passe de aplicação",
     "Login" : "Iniciar Sessão",
     "Password" : "Palavra-passe",
     "Profile" : "Perfil",
+    "Password confirmation is required" : "Confirmação de senha necessária",
     "Server-side encryption" : "Atualizar App",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A cifra do lado do servidor possibilita cifrar os ficheiros que serão enviados para este servidor. Isto implica um impacto no desempenho e só deverá ser ativo quando necessário.",
     "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
@@ -193,7 +187,6 @@ OC.L10N.register(
     "Submit" : "Submeter",
     "Current password" : "Palavra-passe atual",
     "New password" : "Nova palavra-passe",
-    "Change password" : "Alterar palavra-passe",
     "Choose your profile picture" : "Escolher imagem de perfil",
     "Please select a valid png or jpg file" : "Escolha ficheiro png ou jpg válido",
     "Error setting profile picture" : "Erro a definir imagem de perfil",
@@ -208,24 +201,26 @@ OC.L10N.register(
     "Set as profile picture" : "Definir como imagem de perfil",
     "You are a member of the following groups:" : "Membro dos seguintes grupos:",
     "Your full name" : "Nome completo",
+    "No email address set" : "Nenhum endereço de email estabelecido",
     "Email options" : "Opções de correio eletrónico",
     "Remove primary email" : "Remoção de correio eletrónico principal",
     "Delete email" : "Apagar correio eletrónico",
     "Unset as primary email" : "Remove atribuição de correio eletrónico como principal",
-    "No email address set" : "Nenhum endereço de email estabelecido",
     "Help translate" : "Ajude a traduzir",
+    "Week starts on {firstDayOfWeek}" : "Semana começa em {firstDayOfWeek}",
     "Your phone number" : "O seu número de telefone",
     "Add" : "Adicionar",
     "Create" : "Criar",
     "Change" : "Mudar",
-    "Delete" : "Apagar",
+    "Delete" : "Eliminar",
     "Reshare" : "Partilhar novamente",
-    "Display name" : "Nome de apresentação",
+    "Display name" : "Nome a exibir",
     "Email" : "Email",
     "Quota" : "Quota",
     "Language" : "Idioma",
     "Total rows summary" : "Resumo do total de linhas",
     "Avatar" : "Avatar",
+    "Account name" : "Nome da conta",
     "Group admin for" : "Administrador de grupo para",
     "Storage location" : "Localização do armazenamento",
     "Last login" : "Último início de sessão",
@@ -236,7 +231,10 @@ OC.L10N.register(
     "Show last login" : "Mostrar último início de sessão",
     "Send email" : "Enviar email",
     "Default quota" : "Quota padrão",
+    "Security & setup warnings" : "Avisos de configuração e segurança",
+    "All checks passed." : "Todas as verificações passaram.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode afinar o comportamento de partilha. Por favor veja a documentação para mais informação.",
+    "Apply" : "Aplicar",
     "Admins" : "Administrador",
     "Sending…" : "A enviar...",
     "Email sent" : "Mensagem de correio eletrónico enviada",
@@ -249,6 +247,14 @@ OC.L10N.register(
     "Phone number" : "Número de telefone",
     "Role" : "Função",
     "Website" : "Website",
+    "Private" : "Privado",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
+    "Federated" : "Federada",
+    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
+    "Published" : "Publicado",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
     "Your apps" : "As suas apps",
     "Disabled apps" : "Apps desativadas",
     "Updates" : "Atualizações",
@@ -263,6 +269,7 @@ OC.L10N.register(
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicação foi ativada mas necessita ser atualizada. Irá ser redirecionado para a página de atualização em 5 segundos.",
     "Do you really want to wipe your data from this device?" : "Tem a certeza que deseja apagar os dados deste dispositivo?",
     "Confirm wipe" : "Confirmação de limpeza",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Foram efetuados demasiados pedidos a partir da sua rede. Tente mais tarde ou contacte o administrador se for um erro.",
     "Error" : "Erro",
     "Forum" : "Fórum",
     "Legal notice" : "Informação legal",
@@ -280,16 +287,12 @@ OC.L10N.register(
     "Credentials" : "Credenciais",
     "SMTP Password" : "Palavra-passe SMTP",
     "Save" : "Guardar",
-    "Security & setup warnings" : "Avisos de configuração e segurança",
-    "All checks passed." : "Todas as verificações passaram.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolvido pela [communityopen]Comunidade Nextcloud[linkclose]. O [githubcode]código fonte[/linkclose] está licenciado sob [licenseopen]AGPL[linkclose].",
     "Like our Facebook page" : "Deixe um Gosto na nossa página do Facebook",
     "Check out our blog" : "Veja o nosso blog",
     "Subscribe to our newsletter" : "Subscreva as nossas notícias",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis.",
-    "Your biography" : "Biografia",
-    "Username" : "Nome de utilizador",
-    "User backend" : "Backend do utilizador",
-    "Follow us on Twitter" : "Siga-nos no Twitter"
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
