@@ -27,7 +27,6 @@ OC.L10N.register(
     "%s accessed %s" : "%s πρόσβαση %s",
     "%s renamed %s" : "%s μετονομάστηκε%s",
     "%s copied %s" : "%s αντιγράφηκε%s",
-    "%s assigned %s to %s" : "%s ορίστηκε %s σε %s",
     "Operation #%s does not exist" : "Λειτουργία #%s δεν υπάρχει",
     "Entity %s does not exist" : "Η οντότητα %s δεν υπάρχει",
     "Entity %s is invalid" : "Η οντότητα %s δεν είναι έγκυρη",
@@ -56,7 +55,6 @@ OC.L10N.register(
     "PDF documents" : "Έγγραφα PDF",
     "Video" : "Βίντεο",
     "Custom MIME type" : "Προσαρμοσμένος τύπος MIME",
-    "Custom mimetype" : "Προσαρμοσμένος τύπος mime",
     "Select a file type" : "Επιλέξτε τύπο αρχείου",
     "e.g. httpd/unix-directory" : "π.χ. httpd/unix-directory",
     "Please enter a valid time span" : "Εισαγάγετε έγκυρο χρονικό διάστημα",
