@@ -35,31 +35,31 @@ OC.L10N.register(
     "Nextcloud workflow engine" : "Modulo de laborfluo de Nextcloud",
     "Select a filter" : "Elekti filtrilon",
     "Select a comparator" : "Elekti komparilon",
-    "Select a file type" : "Elekti dosierformon",
-    "e.g. httpd/unix-directory" : "ekz. httpd/unix-directory",
+    "Audio" : "Sonaĵo",
     "Folder" : "Dosierujo",
     "Images" : "Bildoj",
     "Office documents" : "Oficejaj dokumentoj",
     "PDF documents" : "PDF-dokumentoj",
-    "Custom mimetype" : "Propra MIME-tipo",
+    "Select a file type" : "Elekti dosierformon",
+    "e.g. httpd/unix-directory" : "ekz. httpd/unix-directory",
     "Please enter a valid time span" : "Entajpu validan intertempon",
-    "Select a request URL" : "Elekti petan retadreson",
     "Files WebDAV" : "Dosieroj WebDAV",
     "Custom URL" : "Propra retadreso",
-    "Select a user agent" : "Elekti retumil-identigilo („user-agent“)",
+    "Select a request URL" : "Elekti petan retadreson",
     "Android client" : "Androida kliento",
     "iOS client" : "iOS-a kliento",
     "Desktop client" : "Labortabla kliento",
     "Thunderbird & Outlook addons" : "Thunderbird-a kaj Outlook-a aldonaĵo",
     "Custom user agent" : "Propra retumil-identigilo („user-agent“)",
+    "Select a user agent" : "Elekti retumil-identigilo („user-agent“)",
     "Select groups" : "Elekti grupojn",
     "Groups" : "Grupoj",
+    "The configuration is invalid" : "La agordo ne validas",
+    "Save" : "Konservi",
     "When" : "Kiam",
     "and" : "kaj",
     "Cancel" : "Nuligi",
     "Delete" : "Forigi",
-    "The configuration is invalid" : "La agordo ne validas",
-    "Save" : "Konservi",
     "Show less" : "Montri malpli",
     "Show more" : "Montri pli",
     "matches" : "kongruas kun",
