@@ -21,13 +21,13 @@ OC.L10N.register(
     "File copied" : "Ficheiro copiado",
     "Tag assigned" : "Etiqueta asignada",
     "Someone" : "Someone",
-    "%s created %s" : "%s creado %s",
-    "%s modified %s" : "%s modificado %s",
-    "%s deleted %s" : "%s eliminado %s",
-    "%s accessed %s" : "%s accedido %s",
-    "%s renamed %s" : "%s renomeado %s",
-    "%s copied %s" : "%s copiado %s",
-    "%s assigned %s to %s" : "%s asignado %s a %s",
+    "%s created %s" : "%s creou %s",
+    "%s modified %s" : "%s modificou %s",
+    "%s deleted %s" : "%s eliminou %s",
+    "%s accessed %s" : "%s accedeu a %s",
+    "%s renamed %s" : "%s renomeou %s",
+    "%s copied %s" : "%s copiou %s",
+    "%1$s assigned %2$s to %3$s" : "%1$s asignou %2$s a %3$s",
     "Operation #%s does not exist" : "Non existe a operación nº %s ",
     "Entity %s does not exist" : "Non existe a entidade %s",
     "Entity %s is invalid" : "A entidade %s é incorrecta",
@@ -49,38 +49,39 @@ OC.L10N.register(
     "Select a filter" : "Seleccione un filtro",
     "Select a comparator" : "Seleccione un comparador",
     "Remove filter" : "Retirar o filtro",
-    "Select a file type" : "Seleccione un tipo de ficheiro",
-    "e.g. httpd/unix-directory" : "p. ex.: httpd/unix-directory",
+    "Audio" : "Son",
     "Folder" : "Cartafol",
     "Images" : "Imaxes",
     "Office documents" : "Documentos de oficina",
     "PDF documents" : "Documentos PDF",
+    "Video" : "Vídeo",
     "Custom MIME type" : "Tipo MIME personalizado",
-    "Custom mimetype" : "Tipo MIME personalizado",
+    "Select a file type" : "Seleccione un tipo de ficheiro",
+    "e.g. httpd/unix-directory" : "p. ex.: httpd/unix-directory",
     "Please enter a valid time span" : "Introduza un intervalo de tempo válido",
-    "Select a request URL" : "Seleccione un URL de solicitude",
     "Files WebDAV" : "Ficheiros WebDAV",
     "Custom URL" : "URL personalizado",
-    "Select a user agent" : "Seleccionar un axente de usuario",
+    "Select a request URL" : "Seleccione un URL de solicitude",
     "Android client" : "Cliente Android",
     "iOS client" : "Cliente iOS",
     "Desktop client" : "Cliente de escritorio",
     "Thunderbird & Outlook addons" : "Complementos do Thunderbird e do Outlook",
     "Custom user agent" : "Axente de usuario personalizado",
+    "Select a user agent" : "Seleccionar un axente de usuario",
     "Select groups" : "Seleccionar grupos",
     "Groups" : "Grupos",
-    "Type to search for group …" : "Escriba para buscar por grupo…",
+    "Type to search for group …" : "Escriba para buscar por grupo…",
     "Select a trigger" : "Seleccione un activador",
     "At least one event must be selected" : "Ten que seleccionar polo menos un evento",
     "Add new flow" : "Engadir un novo fluxo",
+    "The configuration is invalid" : "A configuración é incorrecta",
+    "Active" : "Activo",
+    "Save" : "Gardar",
     "When" : "Cando",
     "and" : "e",
     "Add a new filter" : "Engadir un novo filtro",
     "Cancel" : "Cancelar",
     "Delete" : "Eliminar",
-    "The configuration is invalid" : "A configuración é incorrecta",
-    "Active" : "Activo",
-    "Save" : "Gardar",
     "Available flows" : "Fluxos dispoñíbeis",
     "For details on how to write your own flow, check out the development documentation." : "Para obter máis detalles sobre como escribir o seu propio fluxo, consulte a documentación de desenvolvemento.",
     "No flows installed" : "Non hai ningún fluxo instalado",
@@ -118,6 +119,7 @@ OC.L10N.register(
     "Request user agent" : "Cliente usado para a solicitude",
     "Group membership" : "Pertenza ao grupo",
     "is member of" : "é membro de",
-    "is not member of" : "non é membro de"
+    "is not member of" : "non é membro de",
+    "Type to search for group …" : "Escriba para buscar por grupo…"
 },
 "nplurals=2; plural=(n != 1);");
