@@ -4,7 +4,7 @@ OC.L10N.register(
     "The given operator is invalid" : "Nurodytas operatorius yra neteisingas",
     "The given regular expression is invalid" : "Nurodytas reguliarusis reiškinys yra neteisingas",
     "The given file size is invalid" : "Nurodytas failo dydis yra neteisingas",
-    "The given tag id is invalid" : "Nurodytas žymės id yra neteisingas",
+    "The given tag id is invalid" : "Nurodytas žymos id yra neteisingas",
     "The given IP range is invalid" : "Nurodytas IP rėžis yra neteisingas",
     "The given IP range is not valid for IPv4" : "Nurodytas IPv4 adresas neteisingas",
     "The given IP range is not valid for IPv6" : "Nurodytas IPv6 adresas neteisingas",
@@ -19,7 +19,7 @@ OC.L10N.register(
     "File deleted" : "Failas ištrintas",
     "File accessed" : "Gauta prieiga prie failo",
     "File copied" : "Failas nukopijuotas",
-    "Tag assigned" : "Priskirta žymė",
+    "Tag assigned" : "Priskirta žyma",
     "Someone" : "Kažkas",
     "%s created %s" : "%s sukūrė %s",
     "%s modified %s" : "%s modifikavo %s",
@@ -27,7 +27,6 @@ OC.L10N.register(
     "%s accessed %s" : "%s pasiekiamas %s",
     "%s renamed %s" : "%s pervadino %s",
     "%s copied %s" : "%s nukopijavo %s",
-    "%s assigned %s to %s" : "%s priskyrė %s į %s",
     "Operation #%s does not exist" : "Operacijos #%s nėra",
     "Entity %s does not exist" : "Subjektas %s neegzistuoja",
     "Entity %s is invalid" : "Subjektas %s yra neteisingas",
@@ -46,41 +45,41 @@ OC.L10N.register(
     "Nextcloud workflow engine" : "Nextcloud darbo eigos modulis",
     "Select a filter" : "Pasirinkite filtrą",
     "Select a comparator" : "Pasirinkite palyginimą",
-    "Select a file type" : "Pasirinkite failo tipą",
-    "e.g. httpd/unix-directory" : "pvz., httpd/unix-directory",
+    "Remove filter" : "Šalinti filtrą",
+    "Audio" : "Garso įrašai",
     "Folder" : "Aplankas",
     "Images" : "Paveikslai",
     "Office documents" : "Raštinės dokumentai",
     "PDF documents" : "PDF dokumentai",
-    "Custom mimetype" : "Tinkintas MIME tipas",
-    "Select a tag" : "Pasirinkite žymę",
-    "No results" : "Rezultatų nėra",
-    "%s (invisible)" : "%s (nematomas)",
-    "%s (restricted)" : "%s (apribotas)",
+    "Custom MIME type" : "Tinkintas MIME tipas",
+    "Select a file type" : "Pasirinkite failo tipą",
+    "e.g. httpd/unix-directory" : "pvz., httpd/unix-directory",
     "Please enter a valid time span" : "Įveskite teisingą laiko intervalą",
-    "Select a request URL" : "Pasirinkite užklausos URL",
-    "Predefined URLs" : "Iš anksto apibrėžti URL adresai",
     "Files WebDAV" : "WebDAV failai",
-    "Others" : "Kiti",
     "Custom URL" : "Tinkintas URL",
-    "Select a user agent" : "Pasirinkite naudotojo agentą",
+    "Select a request URL" : "Pasirinkite užklausos URL",
     "Android client" : "Android klientas",
     "iOS client" : "iOS klientas",
     "Desktop client" : "Darbalaukio klientas",
     "Thunderbird & Outlook addons" : "Thunderbird ir Outlook priedai",
     "Custom user agent" : "Tinkintas naudotojo agentas",
+    "Select a user agent" : "Pasirinkite naudotojo agentą",
+    "Select groups" : "Pasirinkti grupes",
+    "Groups" : "Grupės",
     "At least one event must be selected" : "Privalo būti pasirinktas bent vienas įvykis",
     "Add new flow" : "Pridėti naują eigą",
-    "When" : "Kada",
-    "and" : "ir",
-    "Cancel" : "Atsisakyti",
-    "Delete" : "Ištrinti",
     "The configuration is invalid" : "Konfigūracija yra neteisinga",
     "Active" : "Aktyvi",
     "Save" : "Įrašyti",
+    "When" : "Kada",
+    "and" : "ir",
+    "Add a new filter" : "Pridėti naują filtrą",
+    "Cancel" : "Atsisakyti",
+    "Delete" : "Ištrinti",
     "Available flows" : "Prieinamos eigos",
     "For details on how to write your own flow, check out the development documentation." : "Išsamesnę informaciją apie tai, kaip parašyti savo asmeninę eigą, rasite plėtotojo dokumentacijoje.",
     "More flows" : "Daugiau eigų",
+    "Browse the App Store" : "Naršyti programėlių parduotuvę",
     "Show less" : "Rodyti mažiau",
     "Show more" : "Rodyti daugiau",
     "Configured flows" : "Konfigūruotos eigos",
@@ -101,7 +100,7 @@ OC.L10N.register(
     "does not match IPv4" : "neatitinka IPv4",
     "matches IPv6" : "atitinka IPv6",
     "does not match IPv6" : "neatitinka IPv6",
-    "File system tag" : "Failų sistemos žymė",
+    "File system tag" : "Failų sistemos žyma",
     "is tagged with" : "pažymėtas",
     "is not tagged with" : "nepažymėtas",
     "Request URL" : "Užklausos URL",
@@ -109,8 +108,8 @@ OC.L10N.register(
     "between" : "tarp",
     "not between" : "nėra tarp",
     "Request user agent" : "Užklausti naudotojo agentą",
-    "User group membership" : "Naudotojų grupių narystės",
     "is member of" : "priklauso grupei",
-    "is not member of" : "nepriklauso grupei"
+    "is not member of" : "nepriklauso grupei",
+    "Type to search for group …" : "Rašykite norėdami ieškoti grupės…"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
