@@ -8,7 +8,9 @@ declare(strict_types=1);
 namespace OC\Core\Command\Info;
 
 use OC\Files\ObjectStore\ObjectStoreStorage;
+use OC\Files\ObjectStore\PrimaryObjectStoreConfig;
 use OC\Files\Storage\Wrapper\Encryption;
+use OC\Files\Storage\Wrapper\Wrapper;
 use OC\Files\View;
 use OCA\Files_External\Config\ExternalMountPoint;
 use OCA\GroupFolders\Mount\GroupMountPoint;
@@ -34,7 +36,8 @@ class File extends Command {
 	public function __construct(
 		IFactory $l10nFactory,
 		private FileUtils $fileUtils,
-		private \OC\Encryption\Util $encryptionUtil
+		private \OC\Encryption\Util $encryptionUtil,
+		private PrimaryObjectStoreConfig $objectStoreConfig,
 	) {
 		$this->l10n = $l10nFactory->get('core');
 		parent::__construct();
@@ -62,7 +65,7 @@ class File extends Command {
 		$output->writeln($node->getName());
 		$output->writeln('  fileid: ' . $node->getId());
 		$output->writeln('  mimetype: ' . $node->getMimetype());
-		$output->writeln('  modified: ' . (string) $this->l10n->l('datetime', $node->getMTime()));
+		$output->writeln('  modified: ' . (string)$this->l10n->l('datetime', $node->getMTime()));
 
 		if ($node instanceof OCPFile && $node->isEncrypted()) {
 			$output->writeln('  ' . 'server-side encrypted: yes');
@@ -89,13 +92,14 @@ class File extends Command {
 
 		$output->writeln('  size: ' . Util::humanFileSize($node->getSize()));
 		$output->writeln('  etag: ' . $node->getEtag());
+		$output->writeln('  permissions: ' . $this->fileUtils->formatPermissions($node->getType(), $node->getPermissions()));
 		if ($node instanceof Folder) {
 			$children = $node->getDirectoryListing();
 			$childSize = array_sum(array_map(function (Node $node) {
 				return $node->getSize();
 			}, $children));
 			if ($childSize != $node->getSize()) {
-				$output->writeln('    <error>warning: folder has a size of ' . Util::humanFileSize($node->getSize()) ." but it's children sum up to " . Util::humanFileSize($childSize) . '</error>.');
+				$output->writeln('    <error>warning: folder has a size of ' . Util::humanFileSize($node->getSize()) . " but it's children sum up to " . Util::humanFileSize($childSize) . '</error>.');
 				$output->writeln('    Run <info>occ files:scan --path ' . $node->getPath() . '</info> to attempt to resolve this.');
 			}
 			if ($showChildren) {
@@ -143,6 +147,25 @@ class File extends Command {
 			$parts = explode(':', $objectStoreId);
 			/** @var string $bucket */
 			$bucket = array_pop($parts);
+			if ($this->objectStoreConfig->hasMultipleObjectStorages()) {
+				$configs = $this->objectStoreConfig->getObjectStoreConfigs();
+				foreach ($configs as $instance => $config) {
+					if (is_array($config)) {
+						if ($config['arguments']['multibucket']) {
+							if (str_starts_with($bucket, $config['arguments']['bucket'])) {
+								$postfix = substr($bucket, strlen($config['arguments']['bucket']));
+								if (is_numeric($postfix)) {
+									$output->writeln('  object store instance: ' . $instance);
+								}
+							}
+						} else {
+							if ($config['arguments']['bucket'] === $bucket) {
+								$output->writeln('  object store instance: ' . $instance);
+							}
+						}
+					}
+				}
+			}
 			$output->writeln('  bucket: ' . $bucket);
 			if ($node instanceof \OC\Files\Node\File) {
 				$output->writeln('  object id: ' . $storage->getURN($node->getId()));
@@ -174,10 +197,10 @@ class File extends Command {
 		}
 		if ($input->getOption('storage-tree')) {
 			$storageTmp = $storage;
-			$storageClass = get_class($storageTmp).' (cache:'.get_class($storageTmp->getCache()).')';
-			while ($storageTmp instanceof \OC\Files\Storage\Wrapper\Wrapper) {
+			$storageClass = get_class($storageTmp) . ' (cache:' . get_class($storageTmp->getCache()) . ')';
+			while ($storageTmp instanceof Wrapper) {
 				$storageTmp = $storageTmp->getWrapperStorage();
-				$storageClass .= "\n\t".'> '.get_class($storageTmp).' (cache:'.get_class($storageTmp->getCache()).')';
+				$storageClass .= "\n\t" . '> ' . get_class($storageTmp) . ' (cache:' . get_class($storageTmp->getCache()) . ')';
 			}
 			$output->writeln('  storage wrapping: ' . $storageClass);
 		}
