@@ -75,14 +75,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Следните приложения са изключени: %s",
     "Already up to date" : "Актуално",
     "Unknown" : "Неизвестен",
-    "unknown text" : "непознат текст",
-    "Hello world!" : "Здравей Свят!",
-    "sunny" : "слънчево",
-    "Hello {name}, the weather is {weather}" : "Здравейте {name}, времето е {weather}",
-    "Hello {name}" : "Здравейте, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
-    "new" : "нов",
-    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Актуализирането е в процес, в някой среди - напускането на тази страница може да прекъсне процеса.",
     "Update to {version}" : "Актуализирай до {version}",
     "An error occurred." : "Възникна грешка.",
@@ -104,7 +96,6 @@ OC.L10N.register(
     "Search in current app" : "Търси в настоящето приложение",
     "Clear search" : "Изчисти търсенето",
     "Search everywhere" : "Търси навсякъде",
-    "Searching …" : "Търсене ...",
     "Start typing to search" : "Започнете да пишете, за търсене",
     "Today" : "Днес",
     "Last 7 days" : "Последните 7 дни",
@@ -121,7 +112,6 @@ OC.L10N.register(
     "Load more results" : "Зареждане на още резултати",
     "Search in" : "Търси в",
     "Log in" : "Вписване",
-    "Logging in …" : "Вписване ...",
     "Log in to {productName}" : "Вписване в {productName}",
     "This account is disabled" : "Профилът е неактивен",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
@@ -152,20 +142,15 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Документи, електронни таблици и презентации за съвместна работа, създадени в Collabora Online.",
     "Distraction free note taking app." : "Приложение за водене на бележки без разсейване.",
     "Recommended apps" : "Препоръчани приложения",
-    "Loading apps …" : "Зареждане на приложения ...",
     "Could not fetch list of apps from the App Store." : "Списъкът с приложения не можа да се извлече от App Store.",
     "App download or installation failed" : "Изтеглянето или инсталирането на приложението беше неуспешно",
     "Cannot install this app because it is not compatible" : "Това приложение не може да се инсталира, защото е несъвместимо",
     "Cannot install this app" : "Това приложение не може да се инсталира",
     "Skip" : "Пропускане",
-    "Installing apps …" : "Инсталиране на приложения ...",
     "Install recommended apps" : "Инсталиране на препоръчаните приложения ",
     "Settings menu" : "Настройки",
-    "Loading your contacts …" : "Зареждане на контактите ...",
-    "Looking for {term} …" : "Търси се {term} …",
     "Search contacts" : "Търсене в контакти",
     "Reset search" : "Ново търсене",
-    "Search contacts …" : "Търсене в контактите ...",
     "Could not load your contacts" : "Контактите не могат да бъдат заредени",
     "No contacts found" : "Няма намерени контакти",
     "Show all contacts" : "Показване на всички контакти",
@@ -177,7 +162,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Възникна грешка при търсенето на {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Търсенето започва, след като започнете да пишете, а до резултатите можете да стигнете с клавишите със стрелки.",
     "Search for {name} only" : "Търсене само за {name}",
-    "Loading more results …" : "Зарежда още резултати…",
     "Forgot password?" : "Забравена парола?",
     "Back" : "Назад",
     "Login form is disabled." : "Формулярът за вход е деактивиран",
@@ -197,7 +181,6 @@ OC.L10N.register(
     "Database tablespace" : "Tablespace на базата данни",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Моля, посочете номера на порта заедно с името на хоста (напр. Localhost: 5432).",
     "Database host" : "Хост",
-    "Installing …" : "В процес на инсталиране…",
     "Install" : "Инсталиране",
     "Need help?" : "Нуждаете се от помощ?",
     "See the documentation" : "Прегледайте документацията",
@@ -206,9 +189,11 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
     "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
     "Supported versions" : "Поддържани версии",
-    "Search {types} …" : "Търсене на  {types}  ...",
+    "Choose {file}" : "Изберете {file}",
     "Choose" : "Избор",
+    "Copy to {target}" : "Копиране в {target}",
     "Copy" : "Копирай",
+    "Move to {target}" : "Преместване на {target}",
     "Move" : "Премести",
     "OK" : "Добре",
     "read-only" : "Само за четене",
@@ -223,7 +208,7 @@ OC.L10N.register(
     "(all selected)" : "(всички избрани)",
     "({count} selected)" : "({count} избрани)",
     "Error loading file exists template" : "Грешка при зареждането на шаблона за вече съществуващ файл",
-    "Saving …" : "Записване …",
+    "Saving …" : "Запазване ...",
     "seconds ago" : "преди секунди",
     "Connection to server lost" : "Няма връзка със сървъра",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
@@ -238,8 +223,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Въведете, за търсене на съществуващи проекти",
     "New in" : "Ново в",
     "View changelog" : "Преглед на списъка с промени",
-    "No action available" : "Няма налични действия",
-    "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
     "Close \"{dialogTitle}\" dialog" : "Затваряне на диалогов прозорец \"{dialogTitle}\"",
     "Personal" : "Лични",
     "Accounts" : "Профили",
@@ -320,23 +303,34 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
     "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
-    "No temporary profile picture available, try again" : "Не е налична временна профилна снимка, опитайте отново",
-    "No crop data provided" : "Липсват данни за изрязването",
-    "No valid crop data provided" : "Данни за изрязването са невалидни",
-    "Crop is not square" : "Областта не е квадратна",
     "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
     "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чат, видео разговори, споделяне на екрана, онлайн срещи и уеб конферентни връзки - във вашия браузър и с мобилни приложения.",
-    "You have not added any info yet" : "Все още не сте добавили никаква информация",
-    "{user} has not added any info yet" : "{user} все още не е добавил никаква информация",
-    "Error opening the user status modal, try hard refreshing the page" : "Грешка при отваряне на модалния статус на потребителя, опитайте настоятелно да опресните страницата",
-    "Edit Profile" : "Редактиране на профил",
-    "The headline and about sections will show up here" : "Заглавието и секцията за информация ще се покажат тук",
+    "unknown text" : "непознат текст",
+    "Hello world!" : "Здравей Свят!",
+    "sunny" : "слънчево",
+    "Hello {name}, the weather is {weather}" : "Здравейте {name}, времето е {weather}",
+    "Hello {name}" : "Здравейте, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
+    "new" : "нов",
+    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
+    "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда",
+    "Searching …" : "Търсене ...",
+    "Logging in …" : "Вписване ...",
+    "Loading apps …" : "Зареждане на приложения ...",
+    "Installing apps …" : "Инсталиране на приложения ...",
+    "Loading your contacts …" : "Зареждане на контактите ...",
+    "Looking for {term} …" : "Търси се {term} …",
+    "Search contacts …" : "Търсене в контактите ...",
+    "Loading more results …" : "Зарежда още резултати…",
+    "Search {types} …" : "Търсене на  {types}  ...",
+    "Saving …" : "Записване …",
     "Very weak password" : "Много проста парола",
     "Weak password" : "Проста парола",
     "So-so password" : "Не особено добра парола",
     "Good password" : "Добра парола",
     "Strong password" : "Сложна парола",
+    "No action available" : "Няма налични действия",
+    "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
     "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
     "Restricted" : "Ограничен",
     "Invisible" : "Невидим",
@@ -344,8 +338,6 @@ OC.L10N.register(
     "Rename" : "Преименувай",
     "Collaborative tags" : "Съвместни етикети",
     "No tags found" : "Не са открити етикети",
-    "Profile not found" : "Профилът не е намерен",
-    "The profile does not exist." : "Профилът не съществува.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Директория с данни и файлове ви са вероятно са достъпни от Интернет, защото файлът \".htaccess\" не функционира.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Създай администраторски профил</strong>",
@@ -355,6 +347,6 @@ OC.L10N.register(
     "Configure the database" : "Конфигуриране на базата данни",
     "Only %s is available." : "Само %s е наличен.",
     "Database account" : "Профил за база данни",
-    "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда"
+    "Installing …" : "В процес на инсталиране…"
 },
 "nplurals=2; plural=(n != 1);");
